#!/usr/bin/env python3
# coding: utf-8


import numpy as np
from numpy import dot
from numpy.linalg import norm

from methods.solution import Solution
from gensim.models.word2vec import Word2Vec
from gensim.models import KeyedVectors

import os

from methods.common import normalize_model, cosine_similarity

import sys

def normalize_vector(v):
    """
    function that returns the normalized vector of given vector
    :param v: the initial vector
    :return: the normalized vector
    """
    n = np.linalg.norm(v)
    if n == 0:
        return v
    return v / n

def get_vector(v, normalized = False):
    """
    :param v: the given word vector
    :param normalized: boolean value
    :returns either v if norm is set to False or the normalized vector if norm equals True
    """
    if normalized:
        return normalize_vector(v)
    else:
        return v

def main():
    if len(sys.argv) != 2:
        print('Usage: python3 exampleAnalogy.py dataset_location')
        sys.exit()
    dataset_location = sys.argv[1]
    path, dataset_name = os.path.split(dataset_location)

    if "glove" in dataset_location:
        model = KeyedVectors.load_word2vec_format(dataset_location, binary=True)
    else:
        model = Word2Vec.load(dataset_location)
        model = model.wv

    norm_model = normalize_model(model)

    test_analogies = {
        "queen" : Solution(["king","woman"], ["man"]),
         "euro" : Solution(["dollar","europe"],["usa"]),
        "brother": Solution(["sister","man"],["woman"]),
        "berlin" : Solution(["paris","germany"],["france"]),
        "athens" : Solution(["oslo","greece"],["norway"]),
    }
    print(f"dataset : {dataset_name}")
    for target in test_analogies.keys():
        wv_target = norm_model[target]
        wv_analogy = test_analogies.get(target).word_vector(norm_model,len(wv_target))
        cosine = cosine_similarity(wv_target,wv_analogy)
        print(f"cosine for {target} : {cosine:.4f}")





if __name__ == '__main__':
    main()