#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
PEACEWORD, Prototype for Extracting And Considering
           the Explainability of WORD embeddings.
           (c) 2025 University of Lille, CNRS

copyright: Peaceword developers (see Authors file),
           GPL v3 License (see LICENSE file)
"""

from gensim.models.word2vec import Word2Vec

import sys
import gensim.downloader as api

import sys
import csv


def save_model_as_text(filelocation, model):
  with open(filelocation, "w") as f:
    f.write(f"{len(model.wv)} {model.vector_size}\n")
    for word in model.wv.key_to_index.keys():
      f.write(word)
      for value in model.wv[word]:
        f.write(f" {value:.15f}")
      f.write("\n")


def main():
  """
    This simple program loads a gensim dataset and store it into the "models" directory
    Example : python3 load_model_pretrained text8
    """
  if len(sys.argv) < 2:
    print('Usage: load_model_pretrained.py gensimModelName')
    sys.exit()
  corpus = api.load(sys.argv[1])
  model = Word2Vec(corpus)
  model.save(f"./models/{sys.argv[1]}")
  save_model_as_text(f"./models/vectors_{sys.argv[1]}.txt", model)
  print(f"INFO :: model Trained {sys.argv[1]}  saved in ./models")
  print(f"INFO :: word vectors vectors_{sys.argv[1]}.txt  saved in ./models")


if __name__ == '__main__':
  main()