# -*- coding: utf-8 -*-

"""
PEACEWORD, Prototype for Extracting And Considering
           the Explainability of WORD embeddings.
           (c) 2025 University of Lille, CNRS

copyright: Peaceword developers (see Authors file),
           GPL v3 License (see LICENSE file)
"""

from numpy import dot
from numpy.linalg import norm
import numpy as np

def normalize_model(model):
    """
     normalization of gensim KeyedVectors
    Args:
        model: the no normalized downloaded model

    Returns: the corresponding map where all dimensions of the vector words are normalized
             and the elapsed time of the normalization
    """
    # Retrieve keys and corresponding vectors
    keys = list(model.key_to_index.keys())
    vectors = np.stack([model[key] for key in keys])
    normalized_model = {}
    for i_dim in range(model.vector_size):
        vectors.T[i_dim] = vectors.T[i_dim] / max(abs(vectors.T[i_dim]))
    nb = 0
    for word in keys:
        normalized_model[word] = vectors[nb]
        nb = nb + 1

    return normalized_model

def cosine_similarity(vector_a, vector_b) -> float:
    """
    compute the cosine similarity between two vectors

    Arguments:
    vector_a - the first vector
    vector_b - the second vector
    """
    if len(vector_a) == 0:
        return 0.0

    norm_a = norm(vector_a)
    norm_b = norm(vector_b)
    if norm_a == 0.0 or norm_b == 0.0:
        return 0.0
    cos_sim = dot(vector_a, vector_b) / (norm_a * norm_b)
    return cos_sim