#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
PEACEWORD, Prototype for Extracting And Considering
           the Explainability of WORD embeddings.
           (c) 2025 University of Lille, CNRS

copyright: Peaceword developers (see Authors file),
           GPL v3 License (see LICENSE file)
"""


import numpy as np

class Solution:
    def __init__(self, positives=None, negatives=None, _negative_words_in_dataset=False) -> None:
        """ initialisation of a solution with positive and negative set of words
        Args:
            positives: the set of positive words
            negatives: the set of negative words
            negativeWordsInVocab: if true, the dataset map contains entries with negative words,
                                  the word starts with '-' in the dataset map
        """
        if positives is None:
            self.positive = []
        else:
            self.positive = positives
        if negatives is None:
            self.negative = []
        else:
            self.negative = negatives
        self.negative_words_in_dataset = _negative_words_in_dataset

    def is_empty(self):
        """
        :return: true if the solution contains no word, false otherwise
        """
        return  self.size() == 0

    def size(self):
        """ provides the number of words in the solution """
        return len(self.positive) +  len(self.negative)

    def word_vector(self, map_word_vector, vector_size):
        """ computes the corresponding word vector of the solution
        Args:
            map_word_vector : the map corresponding to the dataset
            vector_size: the vector size
        Returns:
            result: the corresponding word vector of the solution
        """
        result = np.zeros(vector_size)
        for word in self.positive:
            result = result + map_word_vector[word]
        for word in self.negative:
            if self.negative_words_in_dataset:
                result = result + map_word_vector["-"+word]
            else:
                result = result - map_word_vector[word]
        return result

    def add(self,word):
        """ add a new word in the  solution
        Args:
            word: the new word, if word starts with the character '-', it is a negative word
        """
        if word[0] == '-':
            self.negative.append(word[1:])
        else:
            self.positive.append(word)

    def __str__(self) -> str:
        str_sol=""
        for s in self.positive:
            str_sol=f"{str_sol}+{s}"
        for s in self.negative:
            str_sol = f"{str_sol}-{s}"
        return str_sol